package com.ruoyi.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import java.util.List;
import com.ruoyi.business.domain.TEbsOrderBak;

/**
 * 流水历史表Mapper接口
 * 
 * @author wms
 * @date 2025-02-26
 */
public interface TEbsOrderBakMapper extends BaseMapper<TEbsOrderBak>
{
    /**
     * 查询流水历史表
     * 
     * @param phasegment1 流水历史表主键
     * @return 流水历史表
     */
    public TEbsOrderBak selectTEbsOrderBakByPhasegment1(String phasegment1);

    /**
     * 查询流水历史表列表
     * 
     * @param tEbsOrderBak 流水历史表
     * @return 流水历史表集合
     */
    public List<TEbsOrderBak> selectTEbsOrderBakList(TEbsOrderBak tEbsOrderBak);

    /**
     * 新增流水历史表
     * 
     * @param tEbsOrderBak 流水历史表
     * @return 结果
     */
    public int insertTEbsOrderBak(TEbsOrderBak tEbsOrderBak);

    /**
     * 修改流水历史表
     * 
     * @param tEbsOrderBak 流水历史表
     * @return 结果
     */
    public int updateTEbsOrderBak(TEbsOrderBak tEbsOrderBak);

    /**
     * 删除流水历史表
     * 
     * @param phasegment1 流水历史表主键
     * @return 结果
     */
    public int deleteTEbsOrderBakByPhasegment1(String phasegment1);

    /**
     * 批量删除流水历史表
     * 
     * @param phasegment1s 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTEbsOrderBakByPhasegment1s(String[] phasegment1s);
}
